@@ -1,6 +1,6 @@
 #include "fftorder.h"
 
-unsigned char fftorder_128[] = {
+const unsigned char fftorder_128[] = {
 0,64,32,96,16,80,112,48,8,72,40,104,120,56,24,88,
 4,68,36,100,20,84,116,52,124,60,28,92,12,76,108,44,
 2,66,34,98,18,82,114,50,10,74,42,106,122,58,26,90,
