@@ -1,5 +1,5 @@
 #include "fftorder.h"
 
-unsigned char fftorder_16[] = {
+const unsigned char fftorder_16[] = {
 0,8,4,12,2,10,14,6,1,9,5,13,15,7,3,11
 } ;
