@@ -1,6 +1,6 @@
 #include "fftorder.h"
 
-unsigned char fftorder_256[] = {
+const unsigned char fftorder_256[] = {
 0,128,64,192,32,160,224,96,16,144,80,208,240,112,48,176,
 8,136,72,200,40,168,232,104,248,120,56,184,24,152,216,88,
 4,132,68,196,36,164,228,100,20,148,84,212,244,116,52,180,
