@@ -1,6 +1,6 @@
 #include "fftorder.h"
 
-unsigned char fftorder_64[] = {
+const unsigned char fftorder_64[] = {
 0,32,16,48,8,40,56,24,4,36,20,52,60,28,12,44,
 2,34,18,50,10,42,58,26,62,30,14,46,6,38,54,22,
 1,33,17,49,9,41,57,25,5,37,21,53,61,29,13,45,
